MoveToPointFuture

Struct MoveToPointFuture 

pub struct MoveToPointFuture<'a, L: ControlLoop<Input = f64, Output = f64> + Unpin, A: ControlLoop<Input = Angle, Output = f64> + Unpin, T: TracksPosition + TracksHeading + TracksVelocity> { /* private fields */ }
Moves the robot to a point using two seeking feedback controllers.

Implementations

Source

impl<L: ControlLoop<Input = f64, Output = f64> + Unpin, A: ControlLoop<Input = Angle, Output = f64> + Unpin, T: TracksPosition + TracksHeading + TracksVelocity> MoveToPointFuture<'_, L, A, T>

pub fn reverse(&mut self) -> &mut Self

Reverses this motion, moving to the point backwards rather than forwards.

pub fn with_linear_controller(&mut self, controller: L) -> &mut Self

Modifies this motion’s linear feedback controller.

pub fn with_angular_controller(&mut self, controller: A) -> &mut Self

Modifies this motion’s angular feedback controller.

pub const fn with_timeout(&mut self, timeout: Duration) -> &mut Self

Modifies this motion’s timeout duration.

pub const fn without_timeout(&mut self) -> &mut Self

Removes this motion’s timeout duration.

pub const fn with_tolerances(&mut self, tolerances: Tolerances) -> &mut Self

Modifies this motion’s tolerances.

pub const fn with_error_tolerance(&mut self, tolerance: f64) -> &mut Self

Modifies this motion’s error tolerance.

pub const fn withear_error_tolerance(&mut self) -> &mut Self

Removes this motion’s error tolerance.

pub const fn with_velocity_tolerance(&mut self, tolerance: f64) -> &mut Self

Modifies this motion’s velocity tolerance.

pub const fn withear_velocity_tolerance(&mut self) -> &mut Self

Removes this motion’s velocity tolerance.

pub const fn with_tolerance_duration(&mut self, duration: Duration) -> &mut Self

Modifies this motion’s tolerance duration.

pub const fn withear_tolerance_duration(&mut self) -> &mut Self

Removes this motion’s tolerance duration.

Source

impl<A: ControlLoop<Input = Angle, Output = f64> + Unpin, T: TracksPosition + TracksHeading + TracksVelocity> MoveToPointFuture<'_, Pid, A, T>

pub const fn with_linear_gains( &mut self, kp: f64, ki: f64, kd: f64, ) -> &mut Self

Modifies this motion’s linear PID gains.

pub const fn with_linear_kp(&mut self, kp: f64) -> &mut Self

Modifies this motion’s linear proportional gain (kp).

pub const fn with_linear_ki(&mut self, ki: f64) -> &mut Self

Modifies this motion’s linear integral gain (ki).

pub const fn with_linear_kd(&mut self, kd: f64) -> &mut Self

Modifies this motion’s linear derivative gain (kd).

pub const fn with_linear_integration_range( &mut self, integration_range: f64, ) -> &mut Self

Modifies this motion’s linear integration range.

pub const fn without_linear_integration_range(&mut self) -> &mut Self

Removes this motion’s linear integration range.

pub const fn with_linear_output_limit(&mut self, limit: f64) -> &mut Self

Modifies this motion’s linear output limit.

pub const fn without_linear_output_limit(&mut self) -> &mut Self

Removes this motion’s linear output limit.

Source

impl<L: ControlLoop<Input = f64, Output = f64> + Unpin, T: TracksPosition + TracksHeading + TracksVelocity> MoveToPointFuture<'_, L, AngularPid, T>

pub const fn with_angular_gains( &mut self, kp: f64, ki: f64, kd: f64, ) -> &mut Self

Modifies this motion’s angular PID gains.

pub const fn with_angular_kp(&mut self, kp: f64) -> &mut Self

Modifies this motion’s angular proportional gain (kp).

pub const fn with_angular_ki(&mut self, ki: f64) -> &mut Self

Modifies this motion’s angular integral gain (ki).

pub const fn with_angular_kd(&mut self, kd: f64) -> &mut Self

Modifies this motion’s angular derivative gain (kd).

pub const fn with_angular_integration_range( &mut self, integration_range: Angle, ) -> &mut Self

Modifies this motion’s angular integration range.

pub const fn with_angular_output_limit(&mut self, limit: f64) -> &mut Self

Modifies this motion’s angular output limit.

pub const fn without_angular_integration_range(&mut self) -> &mut Self

Removes this motion’s angular integration range.

pub const fn without_angular_output_limit(&mut self) -> &mut Self

Removes this motion’s angular output limit.